pub struct PactInteraction { /* private fields */ }Expand description
Opaque type for use as a pointer to a Pact interaction model
Implementations
Sourceimpl PactInteraction
impl PactInteraction
Sourcepub fn new(
interaction: &Box<dyn Interaction + Send + Sync + RefUnwindSafe>,
) -> Self
pub fn new( interaction: &Box<dyn Interaction + Send + Sync + RefUnwindSafe>, ) -> Self
Create a new FFI Pact interaction wrapper for the given Pact interaction model